@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdevicemanager.cpp,v 1.64.2.3 2004/07/17 09:50:08 trueg Exp $
+ * $Id: k3bdevicemanager.cpp,v 1.64.2.5 2004/11/28 12:27:24 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -251,40 +251,23 @@ int K3bCdDevice::DeviceManager::scanbus()
   }
   pclose(fd);
 
-  // we also check all these nodes to make sure to get all links and stuff
 
-//   static const char* devicenames[] = {
-//     "/dev/hda",
-//     "/dev/hdb",
-//     "/dev/hdc",
-//     "/dev/hdd",
-//     "/dev/hde",
-//     "/dev/hdf",
-//     "/dev/hdg",
-//     "/dev/hdh",
-//     "/dev/hdi",
-//     "/dev/hdj",
-//     "/dev/hdk",
-//     "/dev/hdl",
-//     "/dev/dvd",
-//     "/dev/cdrom",
-//     "/dev/cdrecorder",
-//     0
-//   };
-//   int i = 0;
-//   while( devicenames[i] ) {
-//     if( addDevice( devicenames[i] ) )
-//       m_foundDevices++;
-//     ++i;
-//   }
-//   for( int i = 0; i < 16; i++ ) {
-//     if( addDevice( QString("/dev/scd%1").arg(i).ascii() ) )
-//       m_foundDevices++;
-//   }
-//   for( int i = 0; i < 16; i++ ) {
-//     if( addDevice( QString("/dev/sr%1").arg(i).ascii() ) )
-//       m_foundDevices++;
-//   }
+#ifdef Q_OS_LINUX
+  //
+  // Scan the generic devices if we have scsi devices
+  //
+  kdDebug() << "(K3bDevice::DeviceManager) SCANNING FOR GENERIC DEVICES." << endl;
+  for( int i = 0; i < 16; i++ ) {
+    QString sgDev = resolveSymLink( QString("/dev/sg%1").arg(i) );
+    int bus, id, lun;
+    if( determineBusIdLun( sgDev, bus, id, lun ) ) {
+      if( CdDevice* dev = findDevice( bus, id, lun ) ) {
+	dev->m_genericDevice = sgDev;
+      }
+    }
+  }
+  // FIXME: also scan /dev/scsi/hostX.... for devfs without symlinks
+#endif
 
   scanFstab();
 
@@ -390,12 +373,18 @@ bool K3bCdDevice::DeviceManager::saveConfig( KConfig* c )
 
   c->setGroup( "Devices" );
   QStringList deviceSearchPath = c->readListEntry( "device_search_path" );
+  // remove duplicate entries (caused by buggy old implementations)
+  QStringList saveDeviceSearchPath;
+  for( QStringList::iterator it = deviceSearchPath.begin(); it != deviceSearchPath.end(); ++it )
+    if( !saveDeviceSearchPath.contains( *it ) )
+      saveDeviceSearchPath.append( *it );
 
   for( QPtrListIterator<K3bCdDevice::CdDevice> it( d->allDevices ); *it; ++it ) {
     K3bCdDevice::CdDevice* dev = *it;
 
     // update device search path
-    deviceSearchPath.append( dev->blockDeviceName() );
+    if( !saveDeviceSearchPath.contains( dev->blockDeviceName() ) )
+      saveDeviceSearchPath.append( dev->blockDeviceName() );
 
     // save the device type settings
     QString configEntryName = dev->vendor() + " " + dev->description();
@@ -412,7 +401,7 @@ bool K3bCdDevice::DeviceManager::saveConfig( KConfig* c )
     c->writeEntry( configEntryName, list );
   }
 
-  c->writeEntry( "device_search_path", deviceSearchPath );
+  c->writeEntry( "device_search_path", saveDeviceSearchPath );
 
   c->sync();
 
