@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3biso9660imagewritingjob.cpp,v 1.11.2.5 2004/09/23 07:42:11 trueg Exp $
+ * $Id: k3biso9660imagewritingjob.cpp,v 1.11.2.7 2005/03/15 08:57:50 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -302,7 +302,7 @@ bool K3bIso9660ImageWritingJob::prepareWriter( int mediaType )
       if( (m_dataMode == K3b::DATA_MODE_AUTO && m_noFix) ||
 	  m_dataMode == K3b::MODE2 ) {
 	if( k3bcore->externalBinManager()->binObject("cdrecord") && 
-	    k3bcore->externalBinManager()->binObject("cdrecord")->version >= K3bVersion( 2, 1, -1, "a12" ) )
+	    k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "xamix" ) )
 	  writer->addArgument( "-xa" );
 	else
 	  writer->addArgument( "-xa1" );
@@ -365,11 +365,8 @@ bool K3bIso9660ImageWritingJob::prepareWriter( int mediaType )
 				       i18n("No simulation with DVD+R(W)") ) == KMessageBox::No ) {
 	  return false;
 	}
-      }
-      
-      if( m_speed > 0 ) {
-	emit infoMessage( i18n("DVD+R(W) writers do take care of the writing speed themselves."), INFO );
-	emit infoMessage( i18n("The K3b writing speed setting is ignored for DVD+R(W) media."), INFO );
+
+	m_simulate = false;
       }
     }
 
@@ -378,6 +375,7 @@ bool K3bIso9660ImageWritingJob::prepareWriter( int mediaType )
     writer->setBurnSpeed( m_speed );
     writer->setWritingMode( m_writingMode == K3b::DAO ? K3b::DAO : 0 );
     writer->setImageToWrite( m_imagePath );
+    writer->setCloseDvd( !m_noFix );
 
     m_writer = writer;
   }
