@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3baudiodoc.cpp,v 1.18.2.2 2004/04/17 09:37:04 trueg Exp $
+ * $Id: k3baudiodoc.cpp,v 1.18.2.4 2004/09/27 07:18:03 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -299,6 +299,19 @@ bool K3bAudioDoc::readM3uFile( const KURL& url, int pos )
 K3bAudioTrack* K3bAudioDoc::createTrack( const KURL& url )
 {
   QPtrList<K3bPluginFactory> fl = k3bpluginmanager->factories( "AudioDecoder" );
+
+  //
+  // This is an evil hack to force the wave decoder to be checked first since
+  // the mad decoder's canDecode method is not very reliable. :(
+  //
+  for( K3bPluginFactory* factory = fl.first();
+       factory; factory = fl.next() ) {
+    if( factory->isA( "K3bWaveDecoderFactory" ) ) {
+      fl.prepend( fl.take() );
+      break;
+    }
+  }
+  
   for( QPtrListIterator<K3bPluginFactory> it( fl );
        it.current(); ++it ) {
     if( ((K3bAudioDecoderFactory*)it.current())->canDecode( url ) ) {
@@ -488,7 +501,7 @@ bool K3bAudioDoc::loadDocumentData( QDomElement* root )
 	    for( uint trackJ = 0; trackJ < trackNodes.length(); trackJ++ ) {
 	      if( trackNodes.item(trackJ).nodeName() == "cd-text" ) {
 
-		QDomNodeList cdTextNodes = e.childNodes();
+		QDomNodeList cdTextNodes = trackNodes.item(trackJ).childNodes();
 		for( uint trackCdTextJ = 0; trackCdTextJ < cdTextNodes.length(); trackCdTextJ++ ) {
 		  if( cdTextNodes.item(trackCdTextJ).nodeName() == "title" )
 		    track->setTitle( cdTextNodes.item(trackCdTextJ).toElement().text() );
