@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdatadoc.cpp,v 1.21.2.6 2004/02/23 20:39:47 trueg Exp $
+ * $Id: k3bdatadoc.cpp,v 1.21.2.9 2005/03/23 23:01:09 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -33,6 +33,7 @@
 #include <k3btoc.h>
 #include <k3btrack.h>
 #include <k3bmultichoicedialog.h>
+#include <k3bvalidators.h>
 
 #include <qdir.h>
 #include <qstring.h>
@@ -234,10 +235,14 @@ K3bDirItem* K3bDataDoc::createDirItem( QFileInfo& f, K3bDirItem* parent )
       case 5: // rename
 	{
 	  bool ok = true;
+	  QValidator* validator = K3bValidators::iso9660Validator( false, this );
 	  do {
 	    newName = KLineEditDlg::getText( i18n("A file with that name already exists. Please enter a new name."),
-					     newName, &ok, qApp->activeWindow() );
+					     newName, &ok, qApp->activeWindow(), validator );
 	  } while( ok && parent->alreadyInDirectory( newName ) );
+
+	  delete validator;
+
 	  if( !ok )
 	    return 0;
 	}
@@ -341,10 +346,14 @@ K3bFileItem* K3bDataDoc::createFileItem( QFileInfo& f, K3bDirItem* parent )
 	case 5: // rename
 	  {
 	    bool ok = true;
+	    QValidator* validator = K3bValidators::iso9660Validator( false, this );
 	    do {
 	      newName = KLineEditDlg::getText( i18n("A file with that name already exists. Please enter a new name."),
-					       newName, &ok, qApp->activeWindow() );
+					       newName, &ok, qApp->activeWindow(), validator );
 	    } while( ok && parent->alreadyInDirectory( newName ) );
+
+	    delete validator;
+
 	    if( !ok )
 	      return 0;
 	  }
@@ -1299,25 +1308,25 @@ void K3bDataDoc::importSession( K3bCdDevice::CdDevice* device )
 // 		     i18n("Importing old session from %1").arg(device->blockDeviceName()) );
 //   d.show();
 
-  connect( K3bCdDevice::toc( device ), SIGNAL(finished(K3bCdDevice::DeviceHandler*)),
+  connect( K3bCdDevice::diskInfo( device ), SIGNAL(finished(K3bCdDevice::DeviceHandler*)),
 	   this, SLOT(slotTocRead(K3bCdDevice::DeviceHandler*)) );
 }
 
 
 void K3bDataDoc::slotTocRead( K3bCdDevice::DeviceHandler* dh )
 {
-  if( dh->success() && !dh->toc().isEmpty() ) {
+  if( dh->success() && 
+      !dh->toc().isEmpty() &&
+      dh->toc().last().type() == K3bCdDevice::Track::DATA &&
+      dh->ngDiskInfo().appendable() ) {
     K3bCdDevice::Toc::const_iterator it = dh->toc().end();
-    --it; // this is valid since there is at least one data track
-    while( it != dh->toc().begin() && (*it).type() != K3bCdDevice::Track::DATA )
-      --it;
-    long startSec = (*it).firstSector().lba();
+    long startSec = dh->toc().last().firstSector().lba();
     
     // since in iso9660 it is possible that two files share it's data
     // simply summing the file sizes could result in wrong values
     // that's why we use the size from the toc. This is more accurate
     // anyway since there might be files overwritten or removed
-    m_oldSessionSize = (*it).lastSector().mode1Bytes();
+    m_oldSessionSize = dh->toc().last().lastSector().mode1Bytes();
 
     kdDebug() << "(K3bDataDoc) imported session size: " << KIO::convertSize(m_oldSessionSize) << endl;
 
@@ -1475,11 +1484,14 @@ K3bBootItem* K3bDataDoc::createBootItem( const QString& filename, K3bDirItem* di
 
   if( dir->alreadyInDirectory( newName ) ) {
     bool ok = true;
+    QValidator* validator = K3bValidators::iso9660Validator( false, this );
     do {
       newName = KLineEditDlg::getText( i18n("A file with that name already exists. Please enter a new name."),
-				       newName, &ok, qApp->activeWindow() );
+				       newName, &ok, qApp->activeWindow(), validator );
     } while( ok && dir->alreadyInDirectory( newName ) );
-    
+
+    delete validator;    
+
     if( !ok )
       return 0;
   }
