@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bvideodvdimager.h,v 1.1.2.1 2004/02/07 17:56:56 trueg Exp $
+ * $Id: k3bvideodvdimager.h,v 1.1.2.2 2004/07/15 19:24:57 trueg Exp $
  * Copyright (C) 2004 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -39,9 +39,10 @@ class K3bVideoDvdImager : public K3bIsoImager
 
  public slots:
   virtual void start();
+  virtual void calculateSize();
 
  protected:
-  bool addMkisofsParameters();
+  bool addMkisofsParameters( bool printSize = false );
   int writePathSpec();
   void cleanup();
 
