@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3baudiocdview.cpp,v 1.18 2004/01/21 10:20:20 trueg Exp $
+ * $Id: k3baudiocdview.cpp,v 1.18.2.1 2004/06/23 21:21:44 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -217,13 +217,14 @@ void K3bAudioCdView::reload()
   bool useCddb = ( c->readBoolEntry( "use local cddb query", true ) || 
 		   c->readBoolEntry( "use remote cddb", false ) );
 
-  if( m_cdText.isEmpty() ||
-      ( useCddb && KMessageBox::questionYesNo( this, 
-					       i18n("Found Cd-Text. Do you want to use it instead of querying CDDB?"),
-					       i18n("Found Cd-Text"), 
-					       KStdGuiItem::yes(),
-					       KStdGuiItem::no(),
-					       "prefereCdTextOverCddb" ) == KMessageBox::No ) )
+  if( useCddb &&
+      ( m_cdText.isEmpty() ||
+	KMessageBox::questionYesNo( this, 
+				    i18n("Found Cd-Text. Do you want to use it instead of querying CDDB?"),
+				    i18n("Found Cd-Text"), 
+				    KStdGuiItem::yes(),
+				    KStdGuiItem::no(),
+				    "prefereCdTextOverCddb" ) == KMessageBox::No ) )
     queryCddb();
   else
     enableInteraction(true);
